Package {Qindex.data}


Type: Package
Title: Data for (Legacy) Package 'Qindex'
Version: 0.1.4
Date: 2026-08-25
Description: Example data in <doi:10.1186/s12859-023-05408-8> and <doi:10.1016/j.labinv.2023.100158>.
LazyData: true
LazyDataCompression: xz
Encoding: UTF-8
License: GPL-2
Depends: R (≥ 4.6)
Language: en-US
Config/roxygen2/version: 8.1.0
NeedsCompilation: no
Packaged: 2026-08-26 02:26:04 UTC; tingtingzhan
Author: Tingting Zhan [cre, aut], Misung Yi ORCID iD [dtc], Inna Chervoneva ORCID iD [dtc]
Maintainer: Tingting Zhan <tingtingzhan@gmail.com>
Repository: CRAN
Date/Publication: 2026-08-26 02:50:02 UTC

Qindex.data: Data for (Legacy) Package 'Qindex'

Description

Example data in doi:10.1186/s12859-023-05408-8 and doi:10.1016/j.labinv.2023.100158.

Author(s)

Maintainer: Tingting Zhan tingtingzhan@gmail.com

Authors:

Other contributors:


Ki67 Data

Description

Ki67 cell data containing 622 patients.

Usage

Ki67

Format

PATIENT_ID

factor, unique patient identifier

tissueID

factor, TMA core identifier

RECURRENCE

integer, recurrence indicator, 1 = Recurred, 0 = not Recurred

RECFREESURV_MO

integer, recurrence-free survival time in months

Marker

double, cell signal intensity of the protein immunofloerscence signal

inner_x

integer, x-coordinate in the cell centroid in the TMA core

inner_y

integer, y-coordinate in the cell centroid in the TMA core

AGE_AT_DX

integer, age at diagnosis

Tstage

integer, tumor stage

NodeSt

integer, node stage, -1 = unknown, 0 = Node Negative, 1 = Node Positive

HRpos

integer, indicator of hormone positive status (ER+ or PR+), 1 = positive, 0 = negative

HistologicalGrade

integer, histology grade

Her2_path_qIF

integer, Her2 status, 1 = positive, 0 = negative

RACE

character, race, White, Black, Asian, Native Hawaiian or Other Pacific Islander, American Indian or Alaska Native, Unknown

RadjCHEMO

integer, adjuvant chemo treatment, 0 = unknown, 1 = done, 2 = NOT done

RadjRAD

integer, adjuvant radiation treatment, 0 = unknown, 1 = done, 2 = NOT done

HORM_4cat

integer, hormone treatment, 0 = unknown, 1 = not indicated, 2 = done, 3 = recommended, but not done

MSI

double, mean signal intensity (mean over all cells in the TMA core)